@@ -198,9 +198,15 @@ class _ImageBaseHDU(_ValidHDU):
         return data
 
     def _set_data(self, data):
-        self.__dict__['data'] = data
-        self._modified = True
-        if self.data is not None and not isinstance(data, np.ndarray):
+        if 'data' in self.__dict__:
+            if self.__dict__['data'] is data:
+                return
+            else:
+                self._data_replaced = True
+        else:
+            self._data_replaced = True
+
+        if data is not None and not isinstance(data, np.ndarray):
             # Try to coerce the data into a numpy array--this will work, on
             # some level, for most objects
             try:
@@ -209,6 +215,9 @@ class _ImageBaseHDU(_ValidHDU):
                 raise TypeError('data object %r could not be coerced into an '
                                 'ndarray' % data)
 
+        self.__dict__['data'] = data
+        self._modified = True
+
         if isinstance(data, np.ndarray):
             self._bitpix = _ImageBaseHDU.ImgCode[data.dtype.name]
             self._orig_bitpix = self._bitpix
@@ -223,6 +232,10 @@ class _ImageBaseHDU(_ValidHDU):
 
         self.update_header()
 
+        # returning the data signals to lazyproperty that we've already handled
+        # setting self.__dict__['data']
+        return data
+
     data = lazyproperty(data, _set_data)
 
     def update_header(self):
