@@ -2,7 +2,10 @@ from __future__ import division  # confidence high
 from __future__ import with_statement
 
 import gzip
+import mmap
 import os
+import shutil
+import sys
 import warnings
 import zipfile
 
@@ -10,6 +13,7 @@ import numpy as np
 
 import pyfits
 from pyfits.convenience import _getext
+from pyfits.file import _File
 from pyfits.tests import PyfitsTestCase
 from pyfits.tests.util import catch_warnings, BytesIO, ignore_warnings
 
@@ -438,6 +442,45 @@ class TestFileFunctions(PyfitsTestCase):
 
         assert_equal(old_mode, os.stat(filename).st_mode)
 
+    if sys.version_info[:2] > (2, 5):
+        # After a fair bit of experimentation I found that it's more difficult
+        # than it's worth to wrap mmap in Python 2.5.
+        def test_mmap_unwriteable(self):
+            """Regression test for
+            https://github.com/astropy/astropy/issues/968
+
+            Temporarily patches mmap.mmap to exhibit platform-specific bad
+            behavior.
+            """
+
+            class MockMmap(mmap.mmap):
+                def flush(self):
+                    raise mmap.error('flush is broken on this platform')
+
+            old_mmap = mmap.mmap
+            mmap.mmap = MockMmap
+
+            # Force the mmap test to be rerun
+            _File._mmap_available = None
+
+            try:
+                # TODO: Use self.copy_file once it's merged into Astropy
+                shutil.copy(self.data('test0.fits'), self.temp('test0.fits'))
+                with catch_warnings(record=True) as w:
+                    with pyfits.open(self.temp('test0.fits'), mode='update',
+                                     memmap=True) as h:
+                        h[1].data[0, 0] = 999
+
+                    assert len(w) == 1
+                    assert 'mmap.flush is unavailable' in str(w[0].message)
+
+                # Double check that writing without mmap still worked
+                with pyfits.open(self.temp('test0.fits')) as h:
+                    assert h[1].data[0, 0] == 999
+            finally:
+                mmap.mmap = old_mmap
+                _File._mmap_available = None
+
     def _make_gzip_file(self, filename='test0.fits.gz'):
         gzfile = self.temp(filename)
         with open(self.data('test0.fits'), 'rb') as f:
