@@ -251,6 +251,28 @@ class TestHeaderFunctions(PyfitsTestCase):
         assert_equal(header.setdefault('G', 'H'), 'H')
         assert_equal(len(header), 4)
 
+    def test_assign_inf_nan(self):
+        """
+        Regression test for https://github.com/spacetelescope/PyFITS/issues/11
+
+        For the time being it should not be possible to assign the floating
+        point values inf or nan to a header value, since this is not defined by
+        the FITS standard.
+        """
+
+        h = pyfits.Header()
+
+        # There is an obscure cross-platform issue that prevents things like
+        # float('nan') on Windows on older versions of Python; hence it is
+        # unlikely to come up in practice
+        if not (sys.platform.startswith('win32') and
+                sys.version_info[:2] < (2, 6)):
+           assert_raises(ValueError, h.update, 'TEST', float('nan'))
+           assert_raises(ValueError, h.update, 'TEST', float('inf'))
+
+        assert_raises(ValueError, h.update, 'TEST', np.nan)
+        assert_raises(ValueError, h.update, 'TEST', np.inf)
+
 
 class TestRecordValuedKeywordCards(PyfitsTestCase):
     """Tests for handling of record-valued keyword cards as used by the FITS
