@@ -265,6 +265,7 @@ class TestTableFunctions(PyfitsTestCase):
         toto = pyfits.open(self.temp('toto.fits'))
         q = toto[1].data.field('QUAL_SPE')
         assert_true((q[0][4:8] == np.array([0, 0, 0, 0],dtype=np.uint8)).all())
+        assert toto[1].columns[0].format.endswith('J(1571)')
         toto.close()
 
     def test_extend_variable_length_array(self):
@@ -1496,6 +1497,8 @@ class TestTableFunctions(PyfitsTestCase):
         tbhdu.writeto(self.temp('newtable.fits'))
         tbhdu1 = pyfits.open(self.temp('newtable.fits'))
 
+        assert tbhdu1[1].columns[0].format.endswith('D(2)')
+
         for j in range(0,3):
             for i in range(0,len(a[j])):
                 assert_equal(tbhdu1[1].data.field(0)[j][i], a[j][i])
@@ -1509,6 +1512,8 @@ class TestTableFunctions(PyfitsTestCase):
         tbhdu.writeto(self.temp('newtable.fits'))
         tbhdu1 = pyfits.open(self.temp('newtable.fits'))
 
+        assert tbhdu1[1].columns[0].format.endswith('D(2)')
+
         for j in range(0,3):
             for i in range(0,len(a[j])):
                 assert_equal(tbhdu1[1].data.field(0)[j][i], a[j][i])
@@ -1523,6 +1528,8 @@ class TestTableFunctions(PyfitsTestCase):
         tbhdu.writeto(self.temp('newtable.fits'))
         hdul = pyfits.open(self.temp('newtable.fits'))
 
+        assert hdul[1].columns[0].format.endswith('A(3)')
+
         for j in range(0,3):
             for i in range(0,len(a[j])):
                 assert_equal(hdul[1].data.field(0)[j][i], a[j][i])
@@ -1536,6 +1543,8 @@ class TestTableFunctions(PyfitsTestCase):
         tbhdu.writeto(self.temp('newtable.fits'))
         hdul = pyfits.open(self.temp('newtable.fits'))
 
+        assert hdul[1].columns[0].format.endswith('A(3)')
+
         for j in range(0,3):
             for i in range(0,len(a[j])):
                 assert_equal(hdul[1].data.field(0)[j][i], a[j][i])
@@ -1956,3 +1965,22 @@ class TestTableFunctions(PyfitsTestCase):
         arr = [-99] * 20
         col = pyfits.Column('mag', format='E', array=arr)
         assert_true((arr == col.array).all())
+
+    def test_image_none(self):
+        """Regression test
+        for https://github.com/spacetelescope/PyFITS/issues/27
+        """
+
+        with pyfits.open(self.data('tb.fits')) as h:
+            h[1].data
+            h[1].data = None
+            assert_true(isinstance(h[1].data, pyfits.FITS_rec))
+            assert_equal(len(h[1].data), 0)
+            h[1].writeto(self.temp('test.fits'))
+
+        with pyfits.open(self.temp('test.fits')) as h:
+            assert_equal(h[1].header['NAXIS'], 2)
+            assert_equal(h[1].header['NAXIS1'], 12)
+            assert_equal(h[1].header['NAXIS2'], 0)
+            assert_true(isinstance(h[1].data, pyfits.FITS_rec))
+            assert_equal(len(h[1].data), 0)
